@@ -30,41 +30,6 @@
 
 using namespace GettextCatalog;
 
-// GettextImportPlugin::GettextImportPlugin(ExtraDataSaver* extraDataSaver)
-//    : CatalogImportPlugin()
-//    , _extraDataSaver(extraDataSaver)
-GettextImportPlugin::GettextImportPlugin()
-    : CatalogImportPlugin()
-    , _msgidMultiline(false)
-    , _msgstrMultiline(false)
-    , _gettextPluralForm(false)
-    , _testBorked(false)
-    , _obsolete(false)
-    , _msgctxtPresent(false)
-    , _rxMsgCtxt(QStringLiteral("^msgctxt\\s*\".*\"$"))
-    , _rxMsgId(QStringLiteral("^msgid\\s*\".*\"$"))
-    , _rxMsgIdPlural(QStringLiteral("^msgid_plural\\s*\".*\"$"))
-    , _rxMsgIdPluralBorked(QStringLiteral("^msgid_plural\\s*\"?.*\"?$"))
-    , _rxMsgIdBorked(QStringLiteral("^msgid\\s*\"?.*\"?$"))
-    , _rxMsgIdRemQuotes(QStringLiteral("^msgid\\s*\""))
-    , _rxMsgLineRemEndQuote(QStringLiteral("\"$"))
-    , _rxMsgLineRemStartQuote(QStringLiteral("^\""))
-    , _rxMsgLine(QStringLiteral("^\".*\\n?\"$"))
-    , _rxMsgLineBorked(QStringLiteral("^\"?.+\\n?\"?$"))
-    , _rxMsgStr(QStringLiteral("^msgstr\\s*\".*\\n?\"$"))
-    , _rxMsgStrOther(QStringLiteral("^msgstr\\s*\"?.*\\n?\"?$"))
-    , _rxMsgStrPluralStart(QStringLiteral("^msgstr\\[0\\]\\s*\".*\\n?\"$"))
-    , _rxMsgStrPluralStartBorked(QStringLiteral("^msgstr\\[0\\]\\s*\"?.*\\n?\"?$"))
-    , _rxMsgStrPlural(QStringLiteral("^msgstr\\[[0-9]+\\]\\s*\".*\\n?\"$"))
-    , _rxMsgStrPluralBorked(QStringLiteral("^msgstr\\[[0-9]\\]\\s*\"?.*\\n?\"?$"))
-    , _rxMsgStrRemQuotes(QStringLiteral("^msgstr\\s*\"?"))
-//    , _rxMsgId   (QStringLiteral("^msgid\\s*\"?.*\"?$"))
-    , _obsoleteStart(QStringLiteral("#~"))
-    , _msgctxtStart(QStringLiteral("msgctxt"))
-
-{
-}
-
 ConversionStatus GettextImportPlugin::load(QIODevice* device)
 {
     _testBorked = false;
@@ -106,12 +71,12 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
         qCWarning(LOKALIZE_LOG) << "Header entry has non-empty msgid. Creating a temporary header! " << _msgid;
         tempHeader.setMsgid(QString());
         QString tmp(
-            "Content-Type: text/plain; charset=UTF-8\\n" // Unknown charset
+            QStringLiteral("Content-Type: text/plain; charset=UTF-8\\n" // Unknown charset
             "Content-Transfer-Encoding: 8bit\\n"
-            "Mime-Version: 1.0");
+            "Mime-Version: 1.0"));
         tempHeader.setMsgstr(tmp);
         // We keep the comment of the first entry, as it might really be a header comment (at least partially)
-        const QString comment("# Header entry was created by Lokalize.\n#\n" + _comment);
+        const QString comment(QStringLiteral("# Header entry was created by Lokalize.\n#\n") + _comment);
         tempHeader.setComment(comment);
         recoveredErrorInHeader = true;
     } else {
@@ -125,7 +90,7 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
 //    }
 
     // check if header seems to indicate docbook content generated by xml2pot
-    const bool docbookContent = tempHeader.msgstr().contains("application/x-xml2pot");
+    const bool docbookContent = tempHeader.msgstr().contains(QStringLiteral("application/x-xml2pot"));
 
 
 
@@ -162,7 +127,7 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
                 appendCatalogItem(tempCatItem);
                 // check if first comment seems to indicate a docbook source file
                 if (counter == 0)
-                    docbookFile = tempCatItem.comment().contains(".docbook");
+                    docbookFile = tempCatItem.comment().contains(QStringLiteral(".docbook"));
             }
         } else if (Q_UNLIKELY(success == RECOVERED_PARSE_ERROR)) {
             qCDebug(LOKALIZE_LOG) << "Recovered parse error in entry: " << counter;
@@ -257,7 +222,7 @@ QTextCodec* GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCo
     // characters in a template should be either pure ascii or
     // at least utf8, so utf8-codec can be used for both.
     if (charset.contains(QLatin1String("CHARSET"))) {
-        qCDebug(LOKALIZE_LOG) << QString("file seems to be a template: using utf-8 encoding.");
+        qCDebug(LOKALIZE_LOG) << "file seems to be a template: using utf-8 encoding.";
         return QTextCodec::codecForName("utf8");;
     }
 
@@ -331,7 +296,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
         int len = line.length();
         if (len) {
             _trailingNewLines = 0;
-            if (_maxLineLength < len && line.at(0) != '#')
+            if (_maxLineLength < len && line.at(0) != QLatin1Char('#'))
                 _maxLineLength = len;
         } else
             ++_trailingNewLines;
@@ -346,7 +311,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 _obsolete = true;
                 part = Comment;
                 _comment = line;
-            } else if (line.startsWith('#')) {
+            } else if (line.startsWith(QLatin1Char('#'))) {
                 part = Comment;
                 _comment = line;
             } else if (line.startsWith(_msgctxtStart) && line.contains(_rxMsgCtxt)) {
@@ -391,10 +356,10 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
             if (!len && _obsolete) return OK;
             if (!len) continue;
             else if (line.startsWith(_obsoleteStart)) {
-                _comment += ('\n' + line);
+                _comment += (QLatin1Char('\n') + line);
                 _obsolete = true;
-            } else if (line.startsWith('#')) {
-                _comment += ('\n' + line);
+            } else if (line.startsWith(QLatin1Char('#'))) {
+                _comment += (QLatin1Char('\n') + line);
             } else if (line.startsWith(_msgctxtStart) && line.contains(_rxMsgCtxt)) {
                 part = Msgctxt;
 
@@ -419,7 +384,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 part = Msgid;
 
                 // remove quotes at beginning and the end of the lines
-                line.remove(QRegExp("^msgid\\s*\"?"));
+                line.remove(QRegExp(QStringLiteral("^msgid\\s*\"?")));
                 line.remove(_rxMsgLineRemEndQuote);
 
                 _msgidMultiline = line.isEmpty();
@@ -444,7 +409,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 if (_msgctxt.isEmpty())
                     _msgctxt = line;
                 else
-                    _msgctxt += ('\n' + line);
+                    _msgctxt += (QLatin1Char('\n') + line);
                 _msgctxtPresent = true;
             } else if (line.contains(_rxMsgId)) {
                 part = Msgid;
@@ -493,7 +458,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 if (it->isEmpty())
                     (*it) = line;
                 else
-                    (*it) += ('\n' + line);
+                    (*it) += (QLatin1Char('\n') + line);
             } else if (line.contains(_rxMsgIdPlural)) {
                 part = Msgid;
                 _gettextPluralForm = true;
@@ -559,7 +524,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
 
                 if (!line.isEmpty())
                     recoverableError = true;
-            } else if (line.startsWith('#')) {
+            } else if (line.startsWith(QLatin1Char('#'))) {
                 // ### TODO: could this be considered recoverable?
                 qCDebug(LOKALIZE_LOG) << "comment found after a msgid while parsing: " << _msgid.first();
                 error = true;
@@ -588,7 +553,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 if (it->isEmpty())
                     (*it) = line;
                 else
-                    (*it) += ('\n' + line);
+                    (*it) += (QLatin1Char('\n') + line);
             } else {
                 qCDebug(LOKALIZE_LOG) << "no msgstr found after a msgid while parsing: " << _msgid.first();
                 error = true;
@@ -604,7 +569,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 line.remove(_rxMsgLineRemEndQuote);
 
                 if (!(*msgstrIt).isEmpty())
-                    (*msgstrIt) += '\n';
+                    (*msgstrIt) += QLatin1Char('\n');
                 (*msgstrIt) += line;
             } else if (_gettextPluralForm && (line.contains(_rxMsgStrPlural))) {
                 // remove quotes at beginning and the end of the lines
@@ -614,7 +579,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 _msgstr.append(line);
                 msgstrIt = _msgstr.end();
                 --msgstrIt;
-            } else if (line.startsWith('#') || line.startsWith(QStringLiteral("msgid"))) {
+            } else if (line.startsWith(QLatin1Char('#')) || line.startsWith(QStringLiteral("msgid"))) {
                 _errorLine--;
                 _bufferedLine = line;
                 break;
@@ -643,7 +608,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 line.remove(_rxMsgLineRemEndQuote);
 
                 if (!(*msgstrIt).isEmpty())
-                    (*msgstrIt) += '\n';
+                    (*msgstrIt) += QLatin1Char('\n');
                 (*msgstrIt) += line;
             } else {
                 qCDebug(LOKALIZE_LOG) << "no msgid or comment found after a msgstr while parsing: " << _msgstr.last();
