@@ -1,26 +1,11 @@
-/* ****************************************************************************
+/*
   This file is part of Lokalize
 
-  Copyright (C) 2009 by Nick Shaforostoff <shafff@ukr.net>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2009 Nick Shaforostoff <shafff@ukr.net>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-**************************************************************************** */
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "phase.h"
 #include "cmd.h"
@@ -43,7 +28,7 @@ const char* const* processes()
 ProjectLocal::PersonRole roleForProcess(const QString& process)
 {
     int i = ProjectLocal::Undefined;
-    while (i >= 0 && !process.startsWith(processes()[--i]))
+    while (i >= 0 && !process.startsWith(QLatin1String(processes()[--i])))
         ;
     return (i == -1) ? Project::local()->role() : ProjectLocal::PersonRole(i);
 }
@@ -54,7 +39,7 @@ void generatePhaseForCatalogIfNeeded(Catalog* catalog)
         return;
 
     Phase phase;
-    phase.process = processes()[Project::local()->role()];
+    phase.process = QLatin1String(processes()[Project::local()->role()]);
 
     if (initPhaseForCatalog(catalog, phase))
         static_cast<QUndoStack*>(catalog)->push(new UpdatePhaseCmd(catalog, phase));
